# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: v5.2.6.8376
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class Modifier(str, Enum):
    """
    Modifier
    """

    """
    allowed enum values
    """
    NONE = 'none'
    REGIONAL = 'regional'
    SCREENER = 'screener'
    RAWHD = 'rawhd'
    BRDISK = 'brdisk'
    REMUX = 'remux'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Modifier from a JSON string"""
        return cls(json.loads(json_str))


